@@ -1,30 +1,32 @@
-# Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2016, 2020, Oracle and/or its affiliates.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+
 
-from __future__ import with_statement
 
 # import the mforms module for GUI stuff
 import mforms
-import grt
 import threading
 
-import sys, os, csv
+import os
 
-from mforms import newTreeNodeView
+from mforms import newTreeView
 from mforms import FileChooser
 from sqlide_power_import_export_be import create_module
 from workbench.ui import WizardForm, WizardPage, WizardProgressPage
@@ -33,7 +35,9 @@ import operator
 from workbench.utils import Version
 
 
-from workbench.log import log_debug3, log_debug2, log_error, log_info
+from workbench.log import log_error, log_info
+
+from wb_common import to_unicode
 
 last_location = ""
 drop_table = False
@@ -54,13 +58,13 @@ def handleContextMenu(name, sender, args):
     
     for s in selection:
         if s.type == 'db.Schema':
-            user_selection = {'schema': s.name, 'table': None}
+            user_selection = {'schema': to_unicode(s.name), 'table': None}
             break
         elif s.type == 'db.Table':
-            user_selection = {'table': s.name, 'schema': s.schemaName}
+            user_selection = {'table': to_unicode(s.name), 'schema': to_unicode(s.schemaName)}
             break
         elif s.type == 'tables':
-            user_selection = {'table': None, 'schema': s.schemaName}
+            user_selection = {'table': None, 'schema': to_unicode(s.schemaName)}
             break
         else:
             return
@@ -86,20 +90,21 @@ class ResultsPage(WizardPage):
     def create_ui(self):
         if self.main.import_progress_page.import_time:
             itime = float("%d.%d" % (self.main.import_progress_page.import_time.seconds, self.main.import_progress_page.import_time.microseconds))
-            self.content.add(mforms.newLabel(str("File %s was imported in %.3f s" % (self.get_path(), itime))), False, True)
+            text = "File %s was imported in %.3f s" % (self.get_path(), itime)
+            self.content.add(mforms.newLabel(text), False, True)
         
-        
-        self.content.add(mforms.newLabel(str("Table %s.%s %s" % (self.main.destination_table['schema'], 
+        text = "Table %s.%s %s" % (self.main.destination_table['schema'], 
                                                                  self.main.destination_table['table'], 
-                                                                 "has been used" if self.main.destination_page.existing_table_radio.get_active() else "was created"))), False, True)
+                                                                 "has been used" if self.main.destination_page.existing_table_radio.get_active() else "was created")
+        self.content.add(mforms.newLabel(text), False, True)
         self.content.add(mforms.newLabel(str("%d records imported" % self.main.import_progress_page.module.item_count)), False, True)
 
 class ImportProgressPage(WizardProgressPage):
     def __init__(self, owner):
         WizardProgressPage.__init__(self, owner, "Import Data")
 
-        self.add_task(self.prepare_import, "Prepare Import")
-        self.add_threaded_task(self.start_import, "Import data file")
+        self.add_task(self.prepare_import, "Prepare Import", "Prepare Import")
+        self.add_threaded_task(self.start_import, "Import data file", "Import Data Dile")
         self.module = None
         self.stop = None
         self.import_time = None
@@ -139,7 +144,7 @@ class ImportProgressPage(WizardProgressPage):
                 
     def on_close(self):
         if self.module and self.module.is_running:
-            if mforms.ResultOk == mforms.Utilities.show_message("Confirmation", "Do you wish to stop import process?", "Yes", "No",""):
+            if mforms.ResultOk == mforms.Utilities.show_message("Confirmation", "Do you wish to stop the import process?", "Yes", "No",""):
                 self.stop.set()
                 return True
             return False
@@ -187,6 +192,7 @@ class ConfigurationPage(WizardPage):
         format_box.add(mforms.newLabel("Detected file format: %s" % self.input_file_type), False, True)
         if len(self.active_module.options) != 0:
             advanced_opts_btn = mforms.newButton(mforms.ToolButton)
+            advanced_opts_btn.set_size(-1, 16)
             advanced_opts_btn.set_icon(mforms.App.get().get_resource_path("admin_option_file.png"))
             advanced_opts_btn.add_clicked_callback(lambda: self.optpanel.show(False) if self.optpanel.is_shown() else self.optpanel.show(True) )
             format_box.add(advanced_opts_btn, False, True)
@@ -197,7 +203,7 @@ class ConfigurationPage(WizardPage):
             self.optpanel = mforms.newPanel(mforms.TitledBoxPanel)
             self.optpanel.set_title("Options:")
             def set_text_entry(field, output):
-                txt = field.get_string_value().encode('utf-8').strip()
+                txt = field.get_string_value().strip()
                 if len(txt) == 0:
                     operator.setitem(output, 'value', None)
                     mforms.Utilities.add_timeout(0.1, self.call_create_preview_table)
@@ -206,7 +212,7 @@ class ConfigurationPage(WizardPage):
                     mforms.Utilities.add_timeout(0.1, self.call_create_preview_table)
                 else:
                     field.set_value("")
-                    mforms.Utilities.show_error("Import Wizard", "Due to the nature of this wizard, you can't use unicode characters in this place, as also only one character is allowed.","Ok","","")
+                    mforms.Utilities.show_error("Import Wizard", "Due to the nature of this wizard, you can't use unicode characters in this place, as only one character is allowed.","Ok","","")
 
 
             def set_selector_entry(selector, output):
@@ -216,26 +222,26 @@ class ConfigurationPage(WizardPage):
             box = mforms.newBox(False)
             box.set_spacing(8)
             box.set_padding(8)
-            for name, opts in self.active_module.options.iteritems():
+            for name, opts in self.active_module.options.items():
                 label_box = mforms.newBox(True)
                 label_box.set_spacing(8)
-                label_box.add(mforms.newLabel(opts['description']), False, False)
+                label_box.add(mforms.newLabel(opts['description']), False, True)
                 if opts['type'] == 'text':
                     opt_val = mforms.newTextEntry()
                     opt_val.set_size(35, -1)
                     opt_val.set_value(opts['value'])
                     opt_val.add_changed_callback(lambda field = opt_val, output = opts: set_text_entry(field, output))
-                    label_box.add_end(opt_val, False, False)
+                    label_box.add_end(opt_val, False, True)
                     self.opts_mapping[name] = lambda val: opt_val.set_value(val)
                 if opts['type'] == 'select':
                     opt_val = mforms.newSelector()
                     opt_val.set_size(75, -1)
                     opt_val.add_items([v for v in opts['opts']])
-                    opt_val.set_selected(opts['opts'].values().index(opts['value']))
+                    opt_val.set_selected(list(opts['opts'].values()).index(opts['value']))
                     opt_val.add_changed_callback(lambda selector = opt_val, output = opts: set_selector_entry(selector, output))
-                    self.opts_mapping[name] = lambda input, values =  opts['opts'].values(): opt_val.set_selected(values.index(input) if input in values else 0)
-                    label_box.add_end(opt_val, False, False)
-                box.add(label_box, False, False)
+                    self.opts_mapping[name] = lambda input, values =  list(opts['opts'].values()): opt_val.set_selected(values.index(input) if input in values else 0)
+                    label_box.add_end(opt_val, False, True)
+                box.add(label_box, False, True)
             self.optpanel.add(box)
             self.content.add(self.optpanel, False, True)
             self.optpanel.show(False)
@@ -317,15 +323,15 @@ class ConfigurationPage(WizardPage):
     def load_dest_columns(self):
         try:
             rset = self.main.editor.executeManagementQuery("SHOW COLUMNS FROM `%s`.`%s`" % (self.main.destination_table['schema'], self.main.destination_table['table']), 1)
-        except Exception, e:
-            log_error("SHOW COLUMNS FROM `%s`.`%s` : %s" % (self.main.destination_table['schema'], self.main.destination_table['table'], e))
+        except Exception as e:
+            log_error("SHOW COLUMNS FROM `%s`.`%s` : %s" % (self.main.destination_table['schema'], self.main.destination_table['table'], to_unicode(str(e))))
             rset = None
             
         if rset:
             self.dest_cols = []
             ok = rset.goToFirstRow()
             while ok:
-                self.dest_cols.append(rset.stringFieldValueByName("Field"))
+                self.dest_cols.append(to_unicode(rset.stringFieldValueByName("Field")))
                 ok = rset.nextRow()    
     
     def call_create_preview_table(self):
@@ -336,7 +342,7 @@ class ConfigurationPage(WizardPage):
         
         self.create_preview_table(self.call_analyze())
         if self.input_file_type == 'csv' and self.active_module.dialect:
-            for name, opts in self.active_module.options.items():
+            for name, opts in list(self.active_module.options.items()):
                 self.opts_mapping[name](opts['value'])
     
     def call_analyze(self):
@@ -344,7 +350,7 @@ class ConfigurationPage(WizardPage):
         if self.input_file_type == 'csv':
             self.active_module.set_encoding(self.encoding_list[self.encoding_sel.get_string_value()])
         if not self.active_module.analyze_file():
-            mforms.Utilities.show_warning("Table Data Import", "Can't analyze file, please try to change encoding type, if that doesn't help, maybe the file is not: %s, or the file is empty." % self.active_module.title, "Ok", "", "")
+            mforms.Utilities.show_warning("Table Data Import", "Can't analyze file. Please try to change encoding type. If that doesn't help, maybe the file is not: %s, or the file is empty." % self.active_module.title, "Ok", "", "")
             self.last_analyze_status = False
             return False
         self.last_analyze_status = True
@@ -405,7 +411,7 @@ class ConfigurationPage(WizardPage):
             sel = mforms.newSelector()
             sel.set_size(120, -1)
 
-            items = [type for type in type_items.values() if not ((type == "geometry" or type == "json") and self.input_file_type == "json" and not self.is_server_5_7) ]
+            items = [type for type in list(type_items.values()) if not ((type == "geometry" or type == "json") and self.input_file_type == "json" and not self.is_server_5_7) ]
             sel.add_items(items)
             if not self.is_server_5_7 and (row['type'] == "geometry" or row["type"] == "json") and self.input_file_type == "json":
                 row['type'] = "text" # If it's server older than 5.7 we don't have support for geojson so we can't properly import this file, instead we fallback to text
@@ -495,7 +501,7 @@ class ConfigurationPage(WizardPage):
                 self.preview_table.add(create_select_type(row), 3, 4, i+1, i+2, mforms.HFillFlag)
             self.column_mapping.append(row)
             
-        self.treeview_preview = newTreeNodeView(mforms.TreeFlatList)
+        self.treeview_preview = newTreeView(mforms.TreeFlatList)
         for i, col in enumerate(self.active_module._columns):
             self.treeview_preview.add_column(mforms.StringColumnType, str(col['name']), 75, True)
         self.treeview_preview.end_columns()
@@ -522,7 +528,7 @@ class ConfigurationPage(WizardPage):
                 node = self.treeview_preview.add_node()
                 for i, col in enumerate(row):
                     node.set_string(i, str(col))
-
+                        
         self.treeview_preview.set_allow_sorting(True)
         self.treeview_preview.set_size(200, 100)
         self.table_preview_box.add(self.treeview_preview, False, True)
@@ -579,29 +585,30 @@ class SelectDestinationPage(WizardPage):
             self.table_list = {}
             db_list = []
             while ok:
-                dbname = rset.stringFieldValue(0)
+                dbname = to_unicode(rset.stringFieldValue(0))
                 if dbname.strip() in ["mysql", "sys", "information_schema", "fabric", "performance_schema"]:
                     ok = rset.nextRow()
                     continue
                 db_list.append(dbname)
                 ok = rset.nextRow()
-            
-            rset = self.main.editor.executeManagementQuery("SHOW FULL TABLES FROM `%s`" % self.main.destination_table['schema'], 0)
-            if rset:
-                ok = rset.goToFirstRow()
-                while ok:
-                    if rset.stringFieldValue(1) == "BASE TABLE":
-                        table_name = rset.stringFieldValue(0) if not compare_in_lowercase else rset.stringFieldValue(0).lower() 
-                        self.table_list["%s.%s" % (self.main.destination_table['schema'], table_name)] = {'schema': self.main.destination_table['schema'], 'table': table_name} 
-                        
-                    ok = rset.nextRow()
+            if self.main.destination_table['schema']:
+                rset = self.main.editor.executeManagementQuery("SHOW FULL TABLES FROM `%s`" % self.main.destination_table['schema'], 0)
+                if rset:
+                    ok = rset.goToFirstRow()
+                    while ok:
+                        if rset.stringFieldValue(1) == "BASE TABLE":
+                            table_name = to_unicode(rset.stringFieldValue(0)) if not compare_in_lowercase else to_unicode(rset.stringFieldValue(0)).lower()
+                            full_name = "%s.%s" % (self.main.destination_table['schema'], table_name)
+                            self.table_list[full_name] = {'schema': self.main.destination_table['schema'], 'table': table_name} 
+                            
+                        ok = rset.nextRow()
             
             self.destination_table_sel.clear()
-            self.destination_table_sel.add_items(self.table_list.keys())
+            self.destination_table_sel.add_items(list(self.table_list.keys()))
             if self.main.destination_table['schema'] and self.main.destination_table['table']:
                 table_name = "%s.%s" % (self.main.destination_table['schema'], self.main.destination_table['table'])
-                if table_name in self.table_list.keys():
-                    self.destination_table_sel.set_selected(self.table_list.keys().index(table_name))
+                if table_name in list(self.table_list.keys()):
+                    self.destination_table_sel.set_selected(list(self.table_list.keys()).index(table_name))
             self.destination_database_sel.clear()
             self.destination_database_sel.add_items(db_list)
             if self.main.destination_table['schema']:
@@ -675,7 +682,7 @@ class SelectDestinationPage(WizardPage):
             self.truncate_table_cb.show(False)
         table_destination_box.add(self.drop_table_cb, False, True)
         
-        self.content.add(table_destination_box, False, False)
+        self.content.add(table_destination_box, False, True)
         
     def radio_click(self):
         if self.new_table_radio.get_active():
@@ -700,13 +707,13 @@ class SelectDestinationPage(WizardPage):
     def validate(self):
         compare_in_lowercase = self.check_server_lower_case_table_names()
         if self.existing_table_radio.get_active():
-            self.main.destination_table = self.table_list[self.destination_table_sel.get_string_value()]
+            self.main.destination_table = self.table_list[to_unicode(self.destination_table_sel.get_string_value())]
         else:
-            self.main.destination_table['schema'] = self.destination_database_sel.get_string_value()
-            self.main.destination_table['table'] = self.new_table_name.get_string_value().strip()
+            self.main.destination_table['schema'] = to_unicode(self.destination_database_sel.get_string_value())
+            self.main.destination_table['table'] = to_unicode(self.new_table_name.get_string_value()).strip()
             if len(self.main.destination_table['table']) == 0:
                 mforms.Utilities.show_error("Table Import", "You need to specify new table name", "Ok", "", "")
-                return False 
+                return False
             
             if compare_in_lowercase:
                 self.main.destination_table['table'] = self.main.destination_table['table'].lower()
@@ -714,15 +721,15 @@ class SelectDestinationPage(WizardPage):
             table_name = "%s.%s" % (self.main.destination_table['schema'], self.main.destination_table['table'])
 
             if not self.drop_table_cb.get_active() and (table_name in self.table_list or self.check_if_table_exists(self.main.destination_table['schema'], self.main.destination_table['table'])):
-                res = mforms.Utilities.show_message("Table Import", "You specify to create new table, but table with such name already exists in the selected schema. Would you like to drop it, or use existing one and truncate?", "Drop the table", "Use Existing One and Truncate it", "Cancel")
+                res = mforms.Utilities.show_message("Table Import", "You specified to create a new table, but a table with the same name already exists in the selected schema. Would you like to drop it, or use the existing one and truncate?", "Drop the table", "Use Existing One and Truncate it", "Cancel")
                 if res == mforms.ResultOk: 
                     self.drop_table_cb.set_active(True)
                 elif res == mforms.ResultCancel:
                     self.truncate_table_cb.set_active(True)
                     self.existing_table_radio.set_active(True)
-                    self.destination_table_sel.set_selected(self.table_list.keys().index(table_name))
+                    self.destination_table_sel.set_selected(list(self.table_list.keys()).index(table_name))
                 else:
-                    return False 
+                    return False
         return True
 
 class SelectFileWizardPage(WizardPage):
@@ -734,7 +741,7 @@ class SelectFileWizardPage(WizardPage):
     def create_ui(self):
         self.set_spacing(16)
 
-        label = mforms.newLabel("Table Data Import allows you to easily import csv, json datafiles.\nYou can also create destination table on the fly.")
+        label = mforms.newLabel("Table Data Import allows you to easily import CSV, JSON datafiles.\nYou can also create destination table on the fly.")
         label.set_style(mforms.BoldInfoCaptionStyle)
 
         self.content.add(label, False, False)
@@ -750,6 +757,7 @@ class SelectFileWizardPage(WizardPage):
 
         self.importfile_browse_btn = mforms.newButton()
         self.importfile_browse_btn.set_text("Browse...")
+        self.importfile_browse_btn.set_name("Browse")
         self.importfile_browse_btn.add_clicked_callback(self.importfile_browse)
         entry_box.add(self.importfile_browse_btn, False, False)
 
@@ -771,12 +779,12 @@ class SelectFileWizardPage(WizardPage):
             if format.name == fileExt[1:]:
                 break
         else:
-            mforms.Utilities.show_warning("Table Data Import", "This file type is not supported, valid options are: csv, json", "Ok", "", "")
+            mforms.Utilities.show_warning("Table Data Import", "This file type is not supported, valid options are: CSV, JSON", "Ok", "", "")
             return False
         
         if fileExt[1:] == "json":
             if os.path.getsize(file_path) > 104857600:
-                if mforms.Utilities.show_warning("Table Data Import", "This file appears to be a json filetype, and the size is over 100MB. We suggest to get the data in csv format, do you wish to continue?", "Continue", "Cancel", "") != mforms.ResultOk:
+                if mforms.Utilities.show_warning("Table Data Import", "This file appears to be a JSON filetype, and the size is over 100MB, which will take a long time to import. If possible, obtain the data in CSV format instead. Do you wish to continue with this file anyway?", "Continue", "Cancel", "") != mforms.ResultOk:
                     self.importfile_path.set_value("")
                     return False
 
@@ -803,6 +811,7 @@ class PowerImportWizard(WizardForm):
         WizardForm.__init__(self, mforms.Form.main_form())
 
         self.editor = editor
+        self.set_min_size(-1, 650)
         
         self.formats = []
         self.formats.append(create_module("csv", editor, True))
